Available Clients
=================

The following clients are officially recognized as production-ready, and support the current Sentry
protocol:

- Python (`stati-python <http://github.com/intaxi/stati-python>`_)


Client Criteria
---------------

If you're developing a client for your platform, there's several things we highly encourage:

* It should fully implement the current version of the GottWall protocol.

* It should conform to the standard DSN configuration method.

* It should contain an acceptable level of documentation and tests.

* The client should be properly packaged, and named stati-<platform>.
